@@ -34,8 +34,6 @@
 pid_t child_pid;	/* infos about child processes */
 
 void run_rdesktop();
-void sig_child();
-void sig_alarm();
 
 #endif /* __RUN_H__ */
 
